@@ -13,7 +13,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@pahud/cdk-github-oidc", "0.0.8", __name__[0:-6], "cdk-github-oidc@0.0.8.jsii.tgz"
+    "@pahud/cdk-github-oidc",
+    "0.0.12",
+    __name__[0:-6],
+    "cdk-github-oidc@0.0.12.jsii.tgz",
 )
 
 __all__ = [
